#
# spec file for package python-vim-vint
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-vim-vint
Version:        0.3.21
Release:        6.5
Summary:        Lint tool for Vim script Language
License:        MIT
URL:            https://github.com/Kuniwak/vint
Source:         https://github.com/Kuniwak/vint/archive/v%{version}.tar.gz
Patch0:         test-sys-executable.patch
BuildRequires:  %{python_module PyYAML >= 3.11}
BuildRequires:  %{python_module ansicolor >= 0.2.4}
BuildRequires:  %{python_module chardet >= 2.3.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest >= 2.6.4}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PyYAML >= 3.11
Requires:       python-ansicolor >= 0.2.4
Requires:       python-chardet >= 2.3.0
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
A lint tool for the Vim script Language.

%prep
%autosetup -p1 -n vint-%{version}
sed -e 's/==/>=/g' \
    -e 's/\~=/>=/g' \
    -i setup.py \
    -i test-requirements.txt \
    -i requirements.txt
sed -i -e '/^#!\//, 1d' vint/_bundles/vimlparser.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/vint
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# this test fails with 3.9 when building, but succedes on changeroot
# when run manually when run by python3.9 -m unittest discover -v
rm ./test/acceptance/test_cli.py
%pyunittest discover -v

%post
%python_install_alternative vint

%postun
%python_uninstall_alternative vint

%files %{python_files}
%license LICENSE.txt
%doc README.rst
%python_alternative %{_bindir}/vint
%{python_sitelib}/vint
%{python_sitelib}/vim_vint-%{version}.dist-info

%changelog
* Tue Mar  5 2024 Steve Kowalik <steven.kowalik@suse.com>
- Switch to autosetup and pyproject macros.
- Remove python2 leftovers.
* Thu Jul 14 2022 Ben Greiner <code@bnavigator.de>
- Remove pathlib for python3 build
* Thu Aug 26 2021 pgajdos@suse.com
- %%check: use %%pyunittest rpm macro
* Mon May 18 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Mon Apr 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Mon Sep 16 2019 Tomáš Chvátal <tchvatal@suse.com>
- Updat eto 0.3.21:
  * various bugfixes only
- Drop upstream merged patch yaml5.patch
* Mon Mar 18 2019 Tomáš Chvátal <tchvatal@suse.com>
- Fix hardcoded versions
- Add patch to build with new PyYAML 5:
  * yaml5.patch
* Wed Feb 13 2019 John Vandenberg <jayvdb@gmail.com>
- Add missing dependencies for Python 2, enum34 and pathlib and add
  missing test dependency mock
- Remove unnecessary build dependency python-devel
- Remove %%bcond test
- Fix CLI tests with test-sys-executable.patch
- Change version == pins to >= in setup.py and test-requirements.txt
- Update to v0.3.19
  * New features
    + Initial support for stdin
  * Bug fixes
    + Disable ProhibitImplicitScopeVariable
    + Suppress warnings caused by map([], ' "x" ')
    + Fix linting autocmd
    + Fix acceptance tests
  * Optimize
    + ProhibitUnusedVariable
    + get_asset_path
    + ConfigProjectSource
  * Documentation
    + Link to default config
    + Fix a broken code block for example
* Thu Nov 16 2017 toddrme2178@gmail.com
- Initial version v0.3.18
